==> sale-3.2.4.jar: revenue/sqls/MeterCharge/getAllOverdue.sql <==
 --f_oughtfee 应交金额   f_end_date 截止日期  delaypaydate 滞纳天数   delaypay 滞纳金
select f_user_id, 
		sum(f_oughtfee + overdue) as qianfei,
		f_bank_accopen,
		f_bank_account,
		f_bank_idnumber, 
		f_filiale		
from (
 select 
 convert(decimal(18,2),f_oughtfee) f_oughtfee,			--应交金额
 h.f_user_id,
 f_userinfo_id,
 f_bank_accopen,
f_bank_account,
f_bank_idnumber,
f_filiale,
 h.f_balance,    --余额
  --滞纳金 
 --滞纳金=滞纳金比率*滞纳天数*欠费金额
 --滞纳金小于0时：返回0；滞纳金大于欠费金额时，返回f_oughtfee；滞纳金大于0小于欠费金额时，返回滞纳金；
 convert(decimal(18,2),case when overduedays<=0 then 0
	  else (
			case when f_oughtamount + f_totalowe_gas<0 then 0 
				 else  (
						case when f_totalowe_gas<0 then 
								 case when overduedays*zhinajinbilv*(f_oughtfee + f_totalowe_fee-f_balances)>=f_oughtfee + f_totalowe_fee-f_balances
									  then f_oughtfee + f_totalowe_fee-f_balances
									  else overduedays*zhinajinbilv*(f_oughtfee + f_totalowe_fee-f_balances) end
							 else 
								 case when overduedays*zhinajinbilv*f_oughtfee>=f_oughtfee
									  then f_oughtfee
									  else overduedays*zhinajinbilv*f_oughtfee end
							 end
						)
				 end
	       )
	  end)+{ entity.findDialect() == $SqlServer$: $isnull$,$NVL$}(f_overdue,0) overdue
from(
 select h1.*,u.f_balance,case when u.f_balance<0 then 0 else u.f_balance end f_balances from (
 select 
	 id as handplan_id,
	 f_last_tablebase,		
	 f_tablebase,			
	 f_hand_date as f_hand_date,	
	 f_input_date,
	 f_oughtamount,			
	 f_oughtfee,		
	 f_whether_pay,				
	 f_end_date,
	 f_user_id,
	 f_bank_accopen,
	 f_bank_account,
	 f_bank_idnumber,
	 f_filiale,
	 f_surplus_gas,
	 f_haircut_gas,
	 f_share_gas,
	 f_totalowe_fee,
	 f_totalowe_gas,
	 f_overdue,
	 h.f_userinfo_id,	
	 { entity.findDialect() == $SqlServer$:
      $ DATEDIFF(dd,f_end_date,getdate()) $,
      $ floor(cast(sysdate as date)-cast(f_end_date as date))  $
    } overduedays, --滞纳天数
	 case when f_user_type='民用' then (select cast(value as float) from  t_singlevalue where name='民用违约金') else 
	 (select cast(value as float) from  t_singlevalue where name='非民用违约金') end zhinajinbilv							   --滞纳金比率
from V_handplan h
left join 
t_infobank i
on i.f_userinfo_id = h.f_userinfo_id
where f_user_id in (
	select  f.f_user_id
	from t_infobank b
	left join t_userinfo u on b.f_userinfo_id = u.f_userinfo_id
	left join t_userfiles f on u.f_userinfo_id = f.f_userinfo_id
	where b.f_bank_name = '{bankname}' and u.f_user_state = '正常' and u.f_userinfo_id in (select f_userinfo_id from t_infobank where f_bank_name = '{bankname}')
) and  f_whether_pay='否' and f_meter_state = '已抄表'
)  h1
 join
(select f_balance,f_userinfo_id from t_userinfo) u on u.f_userinfo_id=h1.f_userinfo_id
) h 
left join 
(select MIN(f_hand_date) f_hand_date,f_user_id from V_handplan
where f_whether_pay='否' and f_meter_state = '已抄表'
 group by f_user_id
) h1 on h.f_user_id=h1.f_user_id
-- order by h.f_hand_date
) m group by f_user_id, f_bank_account,f_bank_accopen,f_bank_idnumber,f_filiale order by qianfei

==> sale-3.5.3.jar: revenue/sqls/MeterCharge/getAllOverdue.sql <==
 --f_oughtfee 应交金额   f_end_date 截止日期  delaypaydate 滞纳天数   delaypay 滞纳金
select f_user_id, 
		sum(f_oughtfee + overdue) as qianfei,
		f_bank_accopen,
		f_bank_account,
		f_bank_idnumber, 
		f_filiale		
from (
 select 
 convert(decimal(18,2),f_oughtfee) f_oughtfee,			--应交金额
 h.f_user_id,
 f_userinfo_id,
 f_bank_accopen,
f_bank_account,
f_bank_idnumber,
f_filiale,
 h.f_balance,    --余额
  --滞纳金 
 --滞纳金=滞纳金比率*滞纳天数*欠费金额
 --滞纳金小于0时：返回0；滞纳金大于欠费金额时，返回f_oughtfee；滞纳金大于0小于欠费金额时，返回滞纳金；
 convert(decimal(18,2),case when overduedays<=0 then 0
	  else (
			case when f_oughtamount + f_totalowe_gas<0 then 0 
				 else  (
						case when f_totalowe_gas<0 then 
								 case when overduedays*zhinajinbilv*(f_oughtfee + f_totalowe_fee-f_balances)>=f_oughtfee + f_totalowe_fee-f_balances
									  then f_oughtfee + f_totalowe_fee-f_balances
									  else overduedays*zhinajinbilv*(f_oughtfee + f_totalowe_fee-f_balances) end
							 else 
								 case when overduedays*zhinajinbilv*f_oughtfee>=f_oughtfee
									  then f_oughtfee
									  else overduedays*zhinajinbilv*f_oughtfee end
							 end
						)
				 end
	       )
	  end)+{ entity.findDialect() == $SqlServer$: $isnull$,$NVL$}(f_overdue,0) overdue
from(
 select h1.*,u.f_balance,case when u.f_balance<0 then 0 else u.f_balance end f_balances from (
 select 
	 id as handplan_id,
	 f_last_tablebase,		
	 f_tablebase,			
	 f_hand_date as f_hand_date,	
	 f_input_date,
	 f_oughtamount,			
	 f_oughtfee,		
	 f_whether_pay,				
	 f_end_date,
	 f_user_id,
	 f_bank_accopen,
	 f_bank_account,
	 f_bank_idnumber,
	 f_filiale,
	 f_surplus_gas,
	 f_haircut_gas,
	 f_share_gas,
	 f_totalowe_fee,
	 f_totalowe_gas,
	 f_overdue,
	 h.f_userinfo_id,	
	 { entity.findDialect() == $SqlServer$:
      $ DATEDIFF(dd,f_end_date,getdate()) $,
      $ floor(cast(sysdate as date)-cast(f_end_date as date))  $
    } overduedays, --滞纳天数
	 case when f_user_type='民用' then (select top 1 cast(value as float) from  t_singlevalue where name='民用违约金') else
	 (select top 1 cast(value as float) from  t_singlevalue where name='非民用违约金') end zhinajinbilv							   --滞纳金比率
from V_handplan h
left join 
t_infobank i
on i.f_userinfo_id = h.f_userinfo_id
where f_user_id in (
	select  f.f_user_id
	from t_infobank b
	left join t_userinfo u on b.f_userinfo_id = u.f_userinfo_id
	left join t_userfiles f on u.f_userinfo_id = f.f_userinfo_id
	where b.f_bank_name = '{bankname}' and u.f_user_state = '正常' and u.f_userinfo_id in (select f_userinfo_id from t_infobank where f_bank_name = '{bankname}')
) and  f_whether_pay='否' and f_meter_state = '已抄表'
)  h1
 join
(select f_balance,f_userinfo_id from t_userinfo) u on u.f_userinfo_id=h1.f_userinfo_id
) h 
left join 
(select MIN(f_hand_date) f_hand_date,f_user_id from V_handplan
where f_whether_pay='否' and f_meter_state = '已抄表'
 group by f_user_id
) h1 on h.f_user_id=h1.f_user_id
-- order by h.f_hand_date
) m group by f_user_id, f_bank_account,f_bank_accopen,f_bank_idnumber,f_filiale order by qianfei
